==> kdrill3.1.tar.gz: kdrill3.1/externs.h <==
extern void inituse(),readstructs(),initlog();
void usage(),quit();

extern voidMakeWidgets();
extern void initstuffs(int *,char **);

extern struct translationstruct *translations[MAXKANJIALLOWED];
extern Boolean useKanji[MAXKANJIALLOWED];

extern int lowest,highest,numberofkanji;	/* keep track of how many we have */
extern int lowfrequency,highfrequency;		/* for frequency restrictions */
extern char *dictname,*usefile,kanjifontname[];

extern void Beep(),MakeGradeSelect(),MakeFrequency();
extern void printgrades(), parsegrades(char *);

/* widget operators.. */
extern void UnreverseButton(Widget);
extern int GetWidgetNumberval(Widget);
extern void ChangeMode(Widget,XtPointer,XtPointer);
extern void ReverseButton(Widget);

/* other functions */
extern int xtoi(),getline();

/* callbacks */
extern void englishcallback(Widget,XtPointer,XtPointer),
            kanjicallback(Widget,XtPointer,XtPointer),
	    cheatcallback(Widget,XtPointer,XtPointer),
	    usefilecallback(Widget,XtPointer,XtPointer);

extern void SetupGuess(),CountKanji();
extern void DescribeCurrent(int);

extern XFontStruct *largekfont;
extern XFontStruct *smallkfont;
extern XFontStruct *fixedfont;

extern XtAppContext Context;

extern unsigned long black,white;
extern Display	*display;
extern Window	mainwindow,rootwindow;
extern GC	gc,cleargc;

/* buttons n widgets */
extern Widget frequencyForm,frequencyHigh,frequencyLow;
extern Widget buttonform,englishform,kanjiform;
extern Widget gradelevelForm,gradeButtons[];
extern Widget toplevel,form,quitbutton,statusline;
extern Widget usefilebutton;
extern Widget kanjimode,englishmode,togglekana;
extern Widget englishWidget[4],kanjiWidget[4];

extern void setstatus(char *);
/* Accelerator functions.. */
extern void UpdateFrequency(Widget,XEvent *,String *,Cardinal *);
extern void Guessvalue(Widget,XEvent *,String *,Cardinal *);

/* misc resource-level stuffs... */
extern void GetXtString(char *, char *, char *);
extern int GetXtNumber(char *,char *);
extern Boolean GetXtBoolean(char *, char *);

extern Boolean useUsefile; /*	we Always read in a usefile, but
				this says if we actually use it */
extern Boolean doBell,showinorder;
extern Boolean showEnglish;
extern Boolean switchKanaEnglish;
extern int gradelevelflags;
extern FILE *logfile;

extern int Kanji2English;

==> kdrill3.2.tar.gz: kdrill3.2/externs.h <==
extern void inituse(),readstructs(),initlog();
void usage(),quit();

extern voidMakeWidgets();
extern void initstuffs(int *,char **);

extern struct translationstruct *translations[MAXKANJIALLOWED];
extern Boolean useKanji[MAXKANJIALLOWED];

extern int lowest,highest,numberofkanji;	/* keep track of how many we have */
extern int lowfrequency,highfrequency;		/* for frequency restrictions */
extern char *dictname,*usefile,kanjifontname[];

extern void Beep(),MakeGradeSelect(),MakeFrequency();
extern void printgrades(), parsegrades(char *);

/* widget operators.. */
extern void UnreverseButton(Widget);
extern int GetWidgetNumberval(Widget);
extern void ChangeMode(Widget,XtPointer,XtPointer);
extern void ReverseButton(Widget);

/* other functions */
extern int xtoi(),getline();

/* callbacks */
extern void englishcallback(Widget,XtPointer,XtPointer),
            kanjicallback(Widget,XtPointer,XtPointer),
	    cheatcallback(Widget,XtPointer,XtPointer),
	    usefilecallback(Widget,XtPointer,XtPointer);

extern void SetupGuess(),CountKanji();
extern void DescribeCurrent(int);

extern XFontStruct *largekfont;
extern XFontStruct *smallkfont;
extern XFontStruct *fixedfont;

extern XtAppContext Context;

extern unsigned long black,white;
extern Display	*display;
extern Window	mainwindow,rootwindow;
extern GC	gc,cleargc;

/* buttons n widgets */
extern Widget frequencyForm,frequencyHigh,frequencyLow;
extern Widget buttonform,englishform,kanjiform;
extern Widget gradelevelForm,gradeButtons[];
extern Widget toplevel,form,quitbutton,statusline;
extern Widget usefilebutton;
extern Widget kanjimode,englishmode,togglekana;
extern Widget englishWidget[NUMBEROFCHOICES],kanjiWidget[NUMBEROFCHOICES];

extern void setstatus(char *);
/* Accelerator functions.. */
extern void UpdateFrequency(Widget,XEvent *,String *,Cardinal *);
extern void Guessvalue(Widget,XEvent *,String *,Cardinal *);

/* misc resource-level stuffs... */
extern void GetXtString(char *, char *, char *);
extern int GetXtNumber(char *,char *);
extern Boolean GetXtBoolean(char *, char *);

extern Boolean useUsefile; /*	we Always read in a usefile, but
				this says if we actually use it */
extern Boolean doBell,showinorder;
extern Boolean showEnglish;
extern Boolean switchKanaEnglish;
extern int gradelevelflags;
extern FILE *logfile;

extern int Kanji2English;
